comments.CommentType (Comment Type) — amici1

# `comments.CommentType` (Comment Type)

CommentType(id, name, name_de, name_fr)

Master tables : comments.CommentTypes (Comment Types)

Slave tables : comments.CommentsByType (Comments)

Database fields:

- ID (id) : See `<django.db.models.fields.BigAutoField: id>`.

- Designation (name) : See `<lino.utils.mldbc.fields.BabelCharField: name>`.

- Designation (de) (name_de) : See `<django.db.models.fields.CharField: name_de>`.

- Designation (fr) (name_fr) : See `<django.db.models.fields.CharField: name_fr>`.

- Name (name_column) : See `lino.modlib.comments.models.CommentType.name_column`.

- (None) (navigation_panel) : See `lino.modlib.comments.models.CommentType.navigation_panel`.

- Workflow (workflow_buttons) : List of actions that change the workflow state of this object.

- (None) (overview) : See `lino.modlib.comments.models.CommentType.overview`.

Referenced from comments.Comment.comment_type

## Database fields

Internal name | Verbose name | Help text
id | ID |
name | Designation |
name_de | Designation (de) |
name_fr | Designation (fr) |
name_column | Name |
navigation_panel | None |
workflow_buttons | Workflow | List of actions that change the workflow state of this object.
overview | None |